@@ -37,7 +37,10 @@ class MySQLLock(locking.Lock):
         self.acquired = False
         self._conn = MySQLDriver.get_connection(parsed_url, options)
 
-    def acquire(self, blocking=True):
+    def acquire(self, blocking=True, shared=False):
+
+        if shared:
+            raise tooz.NotImplemented
 
         @_retry.retry(stop_max_delay=blocking)
         def _lock():
@@ -63,8 +66,8 @@ class MySQLLock(locking.Lock):
                         self.acquired = True
                         return True
             except pymysql.MySQLError as e:
-                coordination.raise_with_cause(
-                    coordination.ToozError,
+                utils.raise_with_cause(
+                    tooz.ToozError,
                     encodeutils.exception_to_unicode(e),
                     cause=e)
 
@@ -84,9 +87,9 @@ class MySQLLock(locking.Lock):
                 self.acquired = False
                 return True
         except pymysql.MySQLError as e:
-            coordination.raise_with_cause(coordination.ToozError,
-                                          encodeutils.exception_to_unicode(e),
-                                          cause=e)
+            utils.raise_with_cause(tooz.ToozError,
+                                   encodeutils.exception_to_unicode(e),
+                                   cause=e)
 
     def __del__(self):
         if self.acquired:
@@ -178,6 +181,6 @@ class MySQLDriver(coordination.CoordinationDriver):
                                        passwd=password,
                                        database=dbname)
         except (pymysql.err.OperationalError, pymysql.err.InternalError) as e:
-            coordination.raise_with_cause(coordination.ToozConnectionError,
-                                          encodeutils.exception_to_unicode(e),
-                                          cause=e)
+            utils.raise_with_cause(coordination.ToozConnectionError,
+                                   encodeutils.exception_to_unicode(e),
+                                   cause=e)
